package edu.fsu.cs.AccelCollector;

import android.app.Activity;
import android.content.Context;
import android.graphics.Color;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.GridView;
import android.widget.ImageView;
import android.widget.Toast;
import android.widget.AdapterView.OnItemClickListener;

public class LauncherActivity extends Activity implements SensorEventListener{
	private View selected;
	private ImageAdapter images;
	private GridView gridView;
	private SensorManager sensorManager;
	private LogWriter log;
	private boolean isRunning = false;
	private int bodyPosition = -1;

 
	private static final String TAG = "edu.fsu.cs.AccelCollector.LauncherActivity";


	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		//textView = (TextView) findViewById(R.id.textView);
		gridView = (GridView) findViewById(R.id.gridview);
		images = new ImageAdapter(this);
		gridView.setAdapter(images);
		selected = null;

		gridView.setOnItemClickListener(new OnItemClickListener() {
			public void onItemClick(AdapterView<?> parent, View v, int position, long id) {
				//Toast.makeText(LauncherActivity.this, "" + position, Toast.LENGTH_SHORT).show();

				if(isRunning){
					Toast.makeText(LauncherActivity.this, "Turn Monitor Off to Change Locations", Toast.LENGTH_SHORT).show();
					return;
				}
				
				if(selected != null)
					if(isRunning)
						selected.setBackgroundColor(Color.GREEN);
					else
						selected.setBackgroundColor(Color.RED);

				v.setBackgroundColor(Color.YELLOW);

				Toast.makeText(LauncherActivity.this, "Position : " + position, Toast.LENGTH_SHORT).show();
				
				selected = v;
				bodyPosition = position;
			}
		});

		sensorManager = (SensorManager) getSystemService(Context.SENSOR_SERVICE);
	}


	public boolean onCreateOptionsMenu(Menu menu) {
		MenuInflater inflater = getMenuInflater();
		inflater.inflate(R.menu.menu, menu);
		return true;
	}

	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
		case R.id.start:     startMonitor();
		break;
		case R.id.stop:     stopMonitor();
		break;
		}
		return true;
	}

	public void startMonitor(){

		if(bodyPosition == -1){
			Toast.makeText(this, "Please Select Where the Device is Placed", Toast.LENGTH_SHORT).show();
			return;
		}


		if(log != null)
			log.close();

		isRunning = true;
		gridView.setBackgroundColor(Color.GREEN);	
		log = new LogWriter(getString(R.string.file_location), System.currentTimeMillis() + ".txt");
		sensorManager.registerListener(this, sensorManager.getDefaultSensor(Sensor.TYPE_ACCELEROMETER), SensorManager.SENSOR_DELAY_GAME);	
	}


	public void stopMonitor(){
		sensorManager.unregisterListener(this, sensorManager.getDefaultSensor(Sensor.TYPE_ACCELEROMETER));
		
		isRunning = false;
		gridView.setBackgroundColor(Color.RED);
	}
	
	public void onDestory(){
		if(log != null)
			log.close();

		log = null;
	}
	

	public class ImageAdapter extends BaseAdapter {

		private Context context;
		private View views[];

		public ImageAdapter(Context c){
			context = c;
			views = new View[mThumbIds.length];
		}

		public int getCount() {

			return mThumbIds.length;
		}

		public Object getItem(int id) {

			return views[id];
		}

		public long getItemId(int position) {

			return 0;
		}

		public View getView(int position, View convertView, ViewGroup parent) {

			Log.i("TAG", "gettingView " + position);

			ImageView imageView;
			if (convertView == null) {  // if it's not recycled, initialize some attributes
				imageView = new ImageView(context);
				imageView.setLayoutParams(new GridView.LayoutParams(80,80));
				imageView.setScaleType(ImageView.ScaleType.FIT_CENTER);
				imageView.setPadding(0, 0, 0, 0);
			} else {
				imageView = (ImageView) convertView;
			}

			imageView.setImageResource(mThumbIds[position]);
			return views[position] = imageView;
		}

		// references to our images
		private Integer[] mThumbIds = {
				R.drawable.outline00, R.drawable.outline10, R.drawable.outline20, R.drawable.outline00,
				R.drawable.outline00, R.drawable.outline11, R.drawable.outline21, R.drawable.outline00,
				R.drawable.outline02, R.drawable.outline12, R.drawable.outline22, R.drawable.outline32,
				R.drawable.outline03, R.drawable.outline13, R.drawable.outline23, R.drawable.outline33,
				R.drawable.outline00, R.drawable.outline14, R.drawable.outline24, R.drawable.outline00,
				R.drawable.outline00, R.drawable.outline15, R.drawable.outline25, R.drawable.outline00,
				R.drawable.outline00, R.drawable.outline16, R.drawable.outline26, R.drawable.outline00
		};

	}

	public void onAccuracyChanged(Sensor sensor, int accuracy) {

	}

	public void onSensorChanged(SensorEvent event) {
		String line = bodyPosition + "||" + event.timestamp + "||" + event.values[0] + "||" + event.values[1] + "||" + event.values[2];

		Log.i(TAG, "onSensorChanged " + line);
		log.write(line);
	}

}